-- DAHM/DorHUD by DorentuZ` -- http://steamcommunity.com/id/dorentuz/ §§
--

-- NOTE: This file came with an intentional additional '.example' extension so that the real user.lua file will not be
-- replaced on every update. To enable this file, simply remove that extension so that its full file name
-- becomes 'user.lua'. For more info check out the forums at https://steamcommunity.com/groups/dahm4pd/discussions/.

-- MAKE SURE THAT THE FILE IS ALWAYS SAVED USING THE UTF-8 ENCODING OR YOU WILL RUN INTO ISSUES.
-- The standard notepad has options to change the encoding when you save a file.
-- Notepad++ has an 'encoding' submenu where you can easily convert the file to utf-8.
-- Visual Studio Code has similar features at the toolbar in the bottom right. Change if it shows 'ISO-8859'.

-- WARNING: No sanity checks are performed. If you change something to an invalid value,
-- the game can (and usually will) crash or will not load this file at all.

-- These example options are activated by uncommenting them: simply remove the two "--" in front of each line.
-- NOTE: to set a value to nil, you explicitly have to call "D:set_config_option(<key>, nil)". However, it's usually sufficient to set it to false or an empty string.

local is_first_load = ...
local always_reload = true -- if true, then always use values defined in this file and thus ignoring any dynamic changes
local prioritize_gui = false -- if true, then config values defined in this file won't overwrite any existing settings set with the gui

local config = {
	-- strings support argument reordering (e.g. %3$s is the third argument and should be a string)
	-- config options can be found in the base.lua file of each mod folder
	-- most (if not all) xxx_str options can be disabled by setting their value to false

	override_user_config_with_gui_settings = prioritize_gui, -- prioritize this file instead of the gui config (if the above variable is set to false)

	--steam_web_api_key = "ABCDEFGHIJKLMNOPQRSTUVWXYZ012345", -- web api key, request at http://www.steamcommunity.com/dev/apikey
	--chat_log_to_file = "logs/chat.log",

	---- HUD STUFF ----
	--hud_offset_x = 62, -- integer pixel offset from the left
	--hud_offset_y = 30, -- integer pixel offset from the bottom
	--hud_kills_str = "     K: %i/%4$i (%i: s:%6$i/ c:%7$i/ t:%8$i/ d:%9$i - civs:%s) [%5$i%%]",
	--hud_str = false, -- disable the stats line

	-- hud_kills_str vars:
	--   1: total kills
	--   2: total specials kills
	--   3: civs killed (str, conf:hud_kills_civs_str)
	--   4: total head shots
	--   5: accuracy (float)
	--   6: shield kills
	--   7: spooc kills
	--   8: taser kills
	--   9: tank kills
	--  10: total head shots ratio (float)
	--  11: kills per minute (float)
	--  12: total shots
	--  13: total hits
	--  14: weapon accuracy (float)
	--  15: weapon shots
	--  16: weapon hits

	-- many strings support colors; format is as follows (same as libgdx):
	-- > [name] sets the color by name, but there's only a handful defined by default (add new with e.g. Color.orange = Color("FF9900"))
	-- > [#aarrggbb] sets the color by hex value
	-- > [] sets the color to the previous value
	-- > [[ escapes the left bracket

	-- wtfbm format example (with colors):
	--hud_str = "%s     %s",
	--hud_kills_str = "K:%i %n([#ADCAD9]S:%6$i[] [#FFEA00]T:%8$i[] [#00BF00]C:%7$i[] [#E67300]B:%9$i[] [#80A0FF]Civ:%s[])     Acc: %5$.2f%% (%12$i/%13$i) Gun: %14$.2f%% (%15$i/%16$i)",
	--hud_show_downs_restore_in_chat = "all",
	--hud_show_ammo_taken_in_chat = "all",
	--hud_show_downs_in_chat = true, -- print a chat message when someone is downed critically
	--hud_hide_player_downs = true, -- disable the extra stuff that keeps track of your downs
	--hud_hide_peer_downs = true, -- disable the extra stuff that keeps track of other players downs
	--hud_chat_critical_downs_only = false, -- show all downs, not only 'critical' ones
	--hud_critical_bleedout_color_grading = false, -- disable the color grading changes when downed
	--hud_color_grading_change_only_when_downed = true, -- only change color grading when downed (barely visible)
	--hud_bleedout_time_threshold = 4, -- a down is considered critical if at most this many seconds
	--hud_hide_deployable_when_used = "transparent", -- don't remove deployables, but make them transparent instead
	--hud_show_disabled_crew_bonus = false, -- do not make inactive crew bonuses transparent

	--hud_hide_by_default = true, -- only show stats when showing the 'tab' screen
	--hud_show_host_mark = "HOST", -- add an indicator to the hosts name
	--hud_hide_xp_panel = true, -- hide the xp panel when at max level

	hud_name_label_format = "$NAME; [[[peer_color]$LEVEL;[]]", -- add colors to the name label
	hud_mugshot_name_format = "$NAME; [[[peer_color]$LEVEL;[]]", -- add colors to the mugshot name

	--chat_height_multiplier = 3.5, -- general chat height multiplier
	--chat_height_multiplier_ingame = 3, -- chat height multiplier (ingame chat only)
	--chat_input_width_multiplier = 2.5, -- chat width multiplier (ingame chat only)
	--chat_output_position_override = { x = 100, y = 250, is_relative_offset = false }, -- move chat output too (100;250) (ingame chat only)

	---- ANTICHEAT/PROFILE CHECKING STUFF ----
	--perform_playtime_check = true, -- check total ingame time for player
	--check_result_always_visible = true, -- show all profile check results, even the valid ones
	--anticheat_extra_desync_time = 0, -- some events happen in the wrong order and desync can mess up the detection

	---- ADDITIONAL VERIFIED PLAYERS ----
	--player_verification_hardcoded_verified_users = { ["76561193752321071"] = "maxine🍜", ["76561193826994276"] = "❤~sylverium~❤" },

	---- CHANGE THE MATCHMAKING FILTERS ----
	--filter_default_difficulty = 4, -- set the matchmaking filter to overkill by default
	--filter_custom_difficulties = { 4, 5 }, -- add a custom filter that matches both overkill and 145+

	---- ADVANCED KICK EXAMPLE ----
	--kick_with_reason = { -- msg supports the following variables: name, level, mask // kick type: permanent / session / false
	--	{ msg = "Banning '%s' for cheating.", menu = "Ban for cheating", kick_type = "permanent", kick_reason = "cheating" },
	--	{ msg = "Kicking '%s' for not following orders.", menu = "Kick for not listening" },
	--}
	
	---BOTS---
    --ai_mask_set_override = {
      --american = { "tester" }, --tester = secret masks  - troll = troll
      --german = { "tester" },
      --russian = { "tester" },
      --spanish = { "tester" }
    --},
	---- WELCOME MESSAGE EXAMPLE ----
	 --welcome_messages = {{
	   --text = "Welcome to the server",
	   --new_peers_only = true,  -- only show the message once for every peer
	   --host_only = true,       -- only show the message when hosting
	   --as_lobby = true         -- the message is from LOBBY (only works when hosting)
	 --}},

	---- ADVANCED LOGGING ----
	-- log_level = 5,
	-- hud_log_level = 3,
	-- debug_hook_call_logging = 45,
	-- debug_hook_call_orig_logging = false,
	-- debug_hook_call_blacklist = {
		-- module = { ["interact_toggle"] = 1 },
		-- fname = { ["update"] = 1, ["paused_update"] = 1, ["update_timers"] = 1, ["input_multi_choice"] = 1, ["input_kitslot"] = 1 },
		-- class = { ["LocalizationManager"] = 1, ["hud:StatisticsManager"] = 1 },
		-- class_fn = {
			-- ["?.script_data"] = 1,
			-- ["HUDManager._update_name_labels"] = 1,
			-- ["MenuNodeGui._highlight_row_item"] = 1,
			-- ["MenuNodeGui._fade_row_item"] = 1,
			-- ["HUDManager.update_hud_text"] = 1,
		-- },
	-- },
} -- end config


----
-- Override localization strings
--

local localization = {
	menu_inspect_player = " ",
	menu_play_online = " ",
	menu_play_campaign = " ",
	menu_play_single_player = " ",
	menu_visit_forum = " ",
	menu_upgrades = " ",
	menu_quit = " ",
	menu_play_with_friends = " ",
	menu_setup_game = " ",
	menu_play_online_help = " ",
	menu_play_campaign_help = " ",
	menu_play_single_player_help = " ",
	menu_visit_forum_help = " ",
	menu_upgrades_help = " ",
	menu_quit_help = " ",
	menu_play_with_friends_help = " ",
	menu_setup_game_help = " ",
	menu_main_menu = " ",
	dialog_yes = " ",
	dialog_no = " ",
	menu_restart_game = " ",
	menu_kick_player = " ",
	menu_invite_friends = " ",
	menu_end_game = " ",
	dialog_warning_title = " ",
	dialog_are_you_sure_you_want_to_leave_game = " ",
	menu_lobby_campaign_title = " ",
	menu_lobby_difficulty_title = " ",
	menu_leave_lobby = " ",
	menu_start_the_game = " ",
	menu_start_the_game_help = " ",
	menu_lobby = " ",
	menu_create_lobby = " ",
	menu_start_lobby_help = " ",
	menu_toggle_ai = " ",
	menu_toggle_ai_help = " ",
	menu_back = " ",
	menu_campaign = " ",
	dialog_are_you_sure_you_want_to_quit = " ",
	dialog_ask_save_progress_backup = " ",
	menu_brightness = " ",
	menu_advanced_video = " ",
	menu_light_adaption = " ",
	menu_lightfx = " ",
	menu_color_grading = " ",
	menu_brightness_help = " ",
	menu_advanced_video_help = " ",
	menu_light_adaption_help = " ",
	menu_lightfx_help = " ",
	menu_color_grading_help = " ",
	menu_theme_old = " ",
	menu_theme_fire = " ",
	menu_theme_zombie = " ",
	debug_russian = " ",
	debug_german = " ",
	debug_american = " ",
	debug_spanish = " ",
	menu_music_volume = " ",
	menu_sfx_volume = " ",
	menu_voice_volume = " ",
	menu_voicechat_toggle = " ",
	menu_push_to_talk_toggle = " ",
	menu_music_volume_help = " ",
	menu_sfx_volume_help = " ",
	menu_voice_volume_help = " ",
	menu_voicechat_toggle_help = " ",
	menu_push_to_talk_toggle_help = " ",
	menu_options = " ",
	menu_sound = " ",
	menu_controls = " ",
	menu_video = " ",
	menu_option_default = " ",
	menu_clear_progress = " ",
	menu_options_help = " ",
	menu_sound_help = " ",
	menu_controls_help = " ",
	menu_video_help = " ",
	menu_option_default_help = " ",
	menu_clear_progress_help = " ",
	dialog_are_you_sure_you_want_to_clear_progress = " ",
	dialog_default_options_title = " ",
	dialog_default_options_message = " ",
	menu_challenges_help = " ",
	menu_stats = " ",
	menu_stats_help = " ",
	menu_eula = " ",
	menu_eula = " ",
	menu_credits = " ",
	menu_credits_help = " ",
	menu_choose_character = " ",
	menu_choose_character_help = " ",
	menu_choose_mask = " ",
	menu_choose_mask_help = " ",
	menu_difficulty = " ",
	menu_difficulty_help = " ",
	menu_character_random = " ",
	menu_server_title = " ",
	menu_lobby_server_state_title = " ",
	dialog_are_you_sure_you_want_leave = " ",
	debug_weapon_slot1 = " ",
	debug_weapon_slot2 = " ",
	debug_weapon_slot3 = " ",
	debug_deployable_slot1 = " ",
	debug_equipment_slot1 = " ",
	debug_crew_bonus_slot1 = " ",
	debug_ready = " ",
	menu_end_game_help = " ",
	menu_resume_game = " ",
	menu_ingame_menu = " ",
	menu_reputation_permission = " ",
	menu_permission = " ",
	menu_toggle_drop_in = " ",
	menu_toggle_drop_in_help = " ",
	menu_waiting_is_not_ready = " ",
	menu_waiting_is_ready = " ",
	des_glock = " ",
	des_raging_bull = " ",
	des_c45 = " ",
	des_beretta92 = " ",
	des_hk21 = " ",
	des_r870_shotgun = " ",
	des_m14 = " ",
	des_ak47 = " ",
	des_m4 = " ",
	des_mossberg = " ",
	des_m79 = " ",
	des_mp5 = " ",
	des_mac11 = " ",
	des_sentry_gun = " ",
	des_ammo_bag = " ",
	des_doctor_bag = " ",
	des_trip_mine = " ",
	debug_thick_skin = " ",
	des_thick_skin = " ",
	des_extra_start_out_ammo = " ",
	des_toolset = " ",
	des_extra_cable_tie = " ",
	des_more_blood_to_bleed = " ",
	des_more_ammo = " ",
	des_aggressor = " ",
	des_protector = " ",
	des_sharpshooters = " ",
	debug_instruct_mask_on = " ",
	debug_undecided = " ",
	debug_mission_end_continue = " ",
	debug_low_ammo = " ",
	debug_no_ammo = " ",
	menu_press_start = " ",
	debug_equipment_drill = " ",
	mission_get_drill = " ",
	mission_apply_drill = " ",
	debug_interact_drill = " ",
	debug_reload = " ",
	mission_security_footage = " ",
	debug_interact_laptop_objective = " ",
	menu_assault = " ",
	debug_interact_drill_jammed = " ",
	mission_str_catch_hl = " ",
	debug_interact_embassy_door = " ",
	mission_str_meet_hl = " ",
	wp_str_case = " ",
	wp_str_bruce = " ",
	mission_str_reach_hl = " ",
	mission_str_reach2_hl = " ",
	mission_str_extract_hl = " ",
	debug_equipment_gas = " ",
	debug_interact_gas = " ",
	mission_str_parking_hl = " ",
	mission_str_escort_hl = " ",
	wp_str_ba = " ",
	wp_str_aa = " ",
	debug_control_hostages = " ",
	mission_str_wait_hl = " ",
	mission_str_clear_hl = " ",
	debug_interact_doctor_bag_heal = " ",
	mission_str_fail_hl = " ",
	mission_str_exit_hl = " ",
	debug_interact_trip_mine = " ",
	debug_interact_ammo_bag_take_ammo = " ",
	menu_assault_help = " ",
	menu_sharpshooter = " ",
	menu_support = " ",
	menu_technician = " ",
	menu_sharpshooter_help = " ",
	menu_support_help = " ",
	menu_technician_help = " ",
	menu_vsync_help = " ",
	menu_aa_off = " ",
	menu_aa_quick = " ",
	menu_texture_quality_very_low = " ",
	menu_texture_quality_low = " ",
	menu_texture_quality_medium = " ",
	menu_texture_quality_high = " ",
	menu_anisotropic_1 = " ",
	menu_anisotropic_2 = " ",
	menu_anisotropic_4 = " ",
	menu_anisotropic_8 = " ",
	menu_anisotropic_16 = " ",
	menu_anim_lod_1 = " ",
	menu_anim_lod_2 = " ",
	menu_anim_lod_3 = " ",
	menu_streaks = " ",
	menu_vsync = " ",
	menu_colorgrading = " ",
	menu_color_off = " ",
	debug_interact_temp_interact_box_press = " ",
	debug_interact_diamond_case = " ",
	debug_interact_hack_ipad = " ",
	mission_diamond_codes_hl = " ",
	debug_interact_numpad = " ",
	wp_diamond_vault = " ",
	mission_diamond_loot_hl = " ",
	debug_interact_open_door = " ",
	debug_interact_equipment_glass_cutter = " ",
	debug_interact_temp_interact_box = " ",
	debug_interact_diamond = " ",
	mission_diamond_escape_hl = " ",
	wp_diamond_escape = " ",
	mission_diamond_sneak_hl = " ",
	mission_sec_doors_hl = " ",
	wp_diamond_codes = " ",
	debug_interact_being_revived = " ",
	mission_diamond_escort1_hl = " ",
	debug_interact_intimidate = " ",
	mission_diamond_wait_hl = " ",
	mission_diamond_escort2_hl = " ",
	wp_bridge_escort = " ",
	mission_diamond_timelock_hl = " ",
	mission_get_key = " ",
	debug_equipment_bank_manager_key = " ",
	mission_get_into_bank_hl = " ",
	debug_interact_key = " ",
	wp_bank_get_drill = " ",
	debug_interact_copy_machine = " ",
	debug_equipment_thermite = " ",
	wp_bank_drill = " ",
	mission_get_into_vault = " ",
	wp_bank_sec_footage = " ",
	prop_timer_gui_working = " ",
	mission_thermite = " ",
	wp_bank_thermite = " ",
	debug_interact_free = " ",
	debug_interact_thermite = " ",
	mission_thermite_wait = " ",
	debug_interact_equipment_thermite = " ",
	wp_bank_vault = " ",
	mission_empty_vault = " ",
	debug_interact_money_wrap_take_money = " ",
	debug_interact_money_wrap_single_bundle_take = " ",
	wp_bank_trough_lobby = " ",
	mission_trough_lobby = " ",
	mission_blow_wall = " ",
	wp_bank_blow_wall = " ",
	debug_interact_c4 = " ",
	mission_escape = " ",
	wp_bank_escape = " ",
	dialog_request_timed_out_message = " ",
	debug_bank_briefing = " ",
	debug_street_briefing = " ",
	debug_apartment_briefing = " ",
	debug_bridge_briefing = " ",
	debug_diamond_heist_briefing = " ",
	debug_slaughter_house_briefing = " ",
	debug_suburbia_briefing = " ",
	debug_secret_stash_briefing = " ",
	debug_hospital_briefing = " ",
	menu_challenges = " ",
	menu_resolution = " ",
	menu_fullscreen = " ",
	menu_subtitle = " ",
	menu_fov_standard = " ",
	menu_fov_zoom = " ",
	menu_stats_money = " ",
	menu_stats_level_progress = " ",
	menu_stats_time_played = " ",
	menu_stats_favourite_campaign = " ",
	menu_stats_total_completed_campaigns = " ",
	menu_stats_total_completed_objectives = " ",
	menu_stats_challenges_completion = " ",
	menu_stats_favourite_weapon = " ",
	menu_stats_hit_accuracy = " ",
	menu_stats_total_kills = " ",
	menu_stats_total_head_shots = " ",
	menu_visit_more_stats = " ",
	menu_challenges_active = " ",
	menu_challenges_awarded = " ",
	debug_bank = " ",
	debug_street = " ",
	debug_apartment = " ",
	debug_bridge = " ",
	debug_diamond_heist = " ",
	debug_slaughter_house = " ",
	debug_suburbia = " ",
	debug_secret_stash = " ",
	debug_hostpital = " ",
	menu_mask_clowns = " ",
	menu_mask_alienware = " ",
	menu_mask_bf3 = " ",
	menu_mask_santa = " ",
	menu_mask_president = " ",
	menu_mask_gold = " ",
	menu_mask_zombie = " ",
	menu_mask_vyse = " ",
	menu_mask_halloween = " ",
	menu_mask_tester = " ",
	menu_mask_end_of_the_world = " ",
	menu_difficulty_easy = " ",
	menu_difficulty_normal = " ",
	menu_difficulty_hard = " ",
	menu_difficulty_overkill = " ",
	menu_difficulty_overkill_145 = " ",
	menu_global_success = " ",
	menu_difficulty_easy_help = " ",
	menu_difficulty_normal_help = " ",
	menu_difficulty_hard_help = " ",
	menu_difficulty_overkill_help = " ",
	menu_difficulty_overkill_145_help = " ",
	menu_players_online = " ",
	menu_wait = " ",
	mneu_legend_update = " ",
	btn_update = " ",
	dialog_retrieving_servers_title = " ",
	menu_all = " ",
	menu_difficulty_easy = " ",
	menu_difficulty_normal = " ",
	menu_difficulty_hard = " ",
	menu_difficulty_overkill = " ",
	menu_difficulty_overkill_145 = " ",
	menu_diff_filter_help = " ",
	menu_diff_filter = " ",
	menu_lobby_server_title = " ",
	menu_lobby_server_state_in_game = " ",
	menu_lobby_server_state_in_lobby = " ",
	menu_lobby_server_state_loading = " ",
	menu_dist_filter = " ",
	menu_dist_filter_help = " ",
	menu_dist_filter_close = " ",
	menu_dist_filter_far = " ",
	menu_dist_filter_worldwide = " ",
	menu_public_game = " ",
	menu_friends_only_game = " ",
	menu_private_game = " ",
	menu_edit_game_settings = " ",
	menu_lobby_level = " ",
	menu_player_slot_empty = " ",
	debug_exp_level = " ",
	debug_glock = " ",
	debug_raging_bull = " ",
	debug_c45 = " ",
	debug_beretta92 = " ",
	debug_hk21 = " ",
	debug_r870_shotgun = " ",
	debug_m14 = " ",
	debug_ak47 = " ",
	debug_test_raycast_weapon = " ",
	debug_mossberg = " ",
	debug_m79 = " ",
	debug_mp5 = " ",
	debug_mac11 = " ",
	debug_equipment_extra_start_out_ammo = " ",
	debug_toolset = " ",
	debug_equipment_extra_cable_tie = " ",
	debug_upgrade_sharpshooters = " ",
	debug_upgrade_aggressor = " ",
	debug_upgrade_more_blood_to_bleed = " ",
	debug_upgrade_mr_nice_guy = " ",
	debug_upgrade_more_ammo = " ",
	debug_upgrade_protector = " ",
	debug_upgrade_speed_reloaders = " ",
	menu_invite_friends_help = " ",
	menu_kick_player_help = " ",
	menu_restart_game_help = " ",
	menu_resume_game_help = " ",
	menu_eula_help = " ",
	debug_hospital = " ",
	menu_permission_help = " ",
	menu_reputation_permission_help = " ",
	debug_random = " ",
	menu_menu_theme = " ",
	menu_streaks_help = " ",
	menu_antialias_help = " ",
	menu_texture_quality_help = " ",
	menu_anisotropic_help = " ",
	menu_anim_lod_help = " ",
	menu_colorgrading_help = " ",
	menu_fov_standard_help = " ",
	menu_fov_zoom_help = " ",
	menu_menu_theme_help = " ",
	dialog_accept_changes_title = " ",
	menu_stats_time = " ",
	dialog_accept_changes = " ",
	dialog_ok = " ",
	dialog_cancel = " ",
	menu_subtitle_help = " ",
	menu_fullscreen_help = " ",
	menu_lobby_player_slot_avaible = " ",
	des_mr_nice_guy = " ",
	des_speed_reloaders = " ",
	menu_upgrade_progress = " ",
	menu_edit_game_settings_help = " ",
	savefile_saving = " ",
	menu_camera_sensitivity = " ",
	menu_camera_sensitivity_help = " ",
	menu_camera_zoom_sensitivity = " ",
	menu_camera_zoom_sensitivity_help = " ",
	menu_toggle_zoom_sensitivity = " ",
	menu_toggle_zoom_sensitivity_help = " ",
	menu_invert_camera_vertically = " ",
	menu_invert_camera_vertically_help = " ",
	menu_hold_to_steelsight = " ",
	menu_hold_to_steelsight_help = " ",
	menu_hold_to_run = " ",
	menu_hold_to_run = " ",
	menu_hold_to_duck = " ",
	menu_hold_to_duck_help = " ",
	menu_customize_controller = " ",
	menu_customize_controller_help = " ",
	menu_resolution_help = " "
}

----
-- Set a chat command. The following will replace "/dz" with "Watch out! Dozer!" (returning true means you won't see /dz)
D:register_chat_command("dz", "GAME", function(args) -- state options: GAME, MENU (or leave it out)
	Util:say_to_chat("Watch out! Dozer!")            -- helper function to print stuff to the chat
	return true                                      -- eat message; command is not shown in the chat
end)


----
-- Override keybinds
--

local keybind_overrides = {
	--hud_toggle = "f1",
	--hud_timer_start_reset = "f2",
	--hud_toggle_name_labels = "f4",
}


----
-- Create a new keybind
--

-- D:register_keybind("toggle_verbose_logging", "f3", function()
	-- -- change log level
  -- local next_log_level = ((D:conf('log_level') or 0) + 1) % 6
	-- D:set_config_option('log_level', next_log_level, true)
	-- dlog(string.format("Using log level %i.", next_log_level))
-- end)
--D:register_keybind("restart", "f11", "GAME", function()
	--local s = managers.network and managers.network:session()
	--if s and s:amount_of_peers() == 1 then
    --s._profile_check_queue = nil
    --s._cached_profiles = nil

    --local self = _G.MenuCallbackHandler:new()
    --self:update_matchmake_attributes()
    --managers.statistics:stop_session()
    --managers.savefile:save_progress()
    --managers.groupai:state():set_AI_enabled(false)
    --self:lobby_start_the_game()
	--end
--end)
----
-- You can override some functions, but the defaults should be ok for most people.
--

--ProfileChecker = ProfileChecker or {}
--ProfileChecker.short_map_names = {
--	bank = "FWB", heat_street = "HS", bridge = "GB", apartment = "PR", slaughter_house = "SH",
--	diamond_heist = "DH", secret_stash = "UC", suburbia = "CF", hospital = "NM",
--}

--ProfileChecker.short_difficulty_names = { normal = "nrm", overkill = "ovk", overkill_145 = "145+" }

---


---
-- Account specific settings
--

--local steam_id = Steam and Steam:userid()
--if steam_id == "76561197973573096" then
--	-- load from dedicated user.dor.lua file (it can have any name):
--	local f, err = loadfile("user.dor.lua")
--	if f ~= nil then
--		f(...)
--	else
--		-- some error occured
--	end
--end


----
-- Disable modules without removing the folders:
--

-- Disable the profile checker module:
--D:blacklist_module("profile_check")


dlog("Loading user script")


----
-- The tables above are to make it easier. They require the following to actually work, so don't remove anything below.
--

if config then
	local overwrite = not prioritize_gui and (is_first_load or always_reload)
	for key, value in pairs(config) do
		D:set_config_option(key, value, overwrite)
	end
end

if localization then
	for key, value in pairs(localization) do
		D:add_localization_override(key, value)
	end
end

if keybind_overrides then
	for id, key in pairs(keybind_overrides) do
		D:update_keybind(id, key)
	end
end